Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Dir ¶
Dir is for a directory, with scanning contents inside the directory and pass everything to "copy" recursively.
func File ¶
File is for just a file, with considering existence of parent directory and file permission.
func HashFile ¶
HashFile is for just a file, with considering existence of parent directory and file permission.
Types ¶
This section is empty.
Source Files
¶
- copy.go
Click to show internal directories.
Click to hide internal directories.